data:extend(
{
  {
    type = "item",
    name = "petroleum-jelly",
    icon = "__bobwarfare__/graphics/icons/petroleum-jelly.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[petroleum-jelly]",
    stack_size = 100
  },

  {
    type = "item",
    name = "gun-cotton",
    icon = "__bobwarfare__/graphics/icons/gun-cotton.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[gun-cotton]",
    stack_size = 100
  },

  {
    type = "item",
    name = "cordite",
    icon = "__bobwarfare__/graphics/icons/cordite.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[cordite]",
    stack_size = 100
  },


  {
    type = "item",
    name = "bullet-casing",
    icon = "__bobwarfare__/graphics/icons/bullet-casing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-casing]",
    stack_size = 100
  },

  {
    type = "item",
    name = "magazine",
    icon = "__bobwarfare__/graphics/icons/magazine.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[magazine]",
    stack_size = 100
  },


  {
    type = "item",
    name = "bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile]",
    stack_size = 100
  },

  {
    type = "item",
    name = "bullet",
    icon = "__bobwarfare__/graphics/icons/bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet]",
    stack_size = 100
  },


  {
    type = "item",
    name = "ap-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/ap-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-ap]",
    stack_size = 100
  },

  {
    type = "item",
    name = "ap-bullet",
    icon = "__bobwarfare__/graphics/icons/ap-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-ap]",
    stack_size = 100
  },

  {
    type = "item",
    name = "he-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/he-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-he]",
    stack_size = 100
  },

  {
    type = "item",
    name = "he-bullet",
    icon = "__bobwarfare__/graphics/icons/he-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-he]",
    stack_size = 100
  },


  {
    type = "item",
    name = "flame-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/flame-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-flame]",
    stack_size = 100
  },

  {
    type = "item",
    name = "flame-bullet",
    icon = "__bobwarfare__/graphics/icons/flame-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-flame]",
    stack_size = 100
  },


  {
    type = "item",
    name = "acid-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/acid-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-acid]",
    stack_size = 100
  },

  {
    type = "item",
    name = "acid-bullet",
    icon = "__bobwarfare__/graphics/icons/acid-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-acid]",
    stack_size = 100
  },


  {
    type = "item",
    name = "poison-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/poison-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-poison]",
    stack_size = 100
  },

  {
    type = "item",
    name = "poison-bullet",
    icon = "__bobwarfare__/graphics/icons/poison-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-poison]",
    stack_size = 100
  },


  {
    type = "item",
    name = "impact-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/impact-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-impact]",
    stack_size = 100
  },

  {
    type = "item",
    name = "impact-bullet",
    icon = "__bobwarfare__/graphics/icons/impact-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-impact]",
    stack_size = 100
  },


  {
    type = "item",
    name = "shotgun-shell-casing",
    icon = "__bobwarfare__/graphics/icons/shotgun-shell-casing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[shotgun-shell-casing]",
    stack_size = 100
  },

  {
    type = "item",
    name = "shot",
    icon = "__bobwarfare__/graphics/icons/shot.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[shot]",
    stack_size = 500
  },


  {
    type = "item",
    name = "laser-rifle-battery-case",
    icon = "__bobwarfare__/graphics/icons/laser-rifle-battery-case.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[laser-rifle-battery-case]",
    stack_size = 100
  },


  {
    type = "item",
    name = "rocket-engine",
    icon = "__bobwarfare__/graphics/icons/rocket-engine.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f[rocket-engine]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rocket-body",
    icon = "__bobwarfare__/graphics/icons/rocket-body.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[rocket-body]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "piercing-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-pierce.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[piercing-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "impact-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-impact.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[impact-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "explosive-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-explosive.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[explosive-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "acid-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-acid.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[acid-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "flame-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-fire.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[flame-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "poison-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-poison.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[poison-rocket-warhead]",
    stack_size = 100
  },
}
)


