require("prototypes.category")

require("prototypes.entity.accumulators")
require("prototypes.entity.boilers")
require("prototypes.entity.poles")
require("prototypes.entity.solar-panels")
require("prototypes.entity.steam-engines")

require("prototypes.item.accumulators")
require("prototypes.item.boilers")
require("prototypes.item.poles")
require("prototypes.item.solar-panels")
require("prototypes.item.steam-engines")

require("prototypes.recipe.accumulators")
require("prototypes.recipe.boilers")
require("prototypes.recipe.poles")
require("prototypes.recipe.solar-panels")
require("prototypes.recipe.steam-engines")

require("prototypes.technology.accumulators")
require("prototypes.technology.boilers")
require("prototypes.technology.poles")
require("prototypes.technology.solar-panels")
require("prototypes.technology.steam-engines")

