data:extend(
{
  {
    type = "recipe",
    name = "roboport-antenna-1",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 1},
      {"copper-cable", 2},
      {"advanced-circuit", 5},
    },
    result = "roboport-antenna-1",
    energy_required = 0.2
  },
  {
    type = "recipe",
    name = "roboport-antenna-2",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 1},
      {"copper-cable", 2},
      {"advanced-circuit", 5},
    },
    result = "roboport-antenna-2",
    energy_required = 0.2
  },
  {
    type = "recipe",
    name = "roboport-antenna-3",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 1},
      {"copper-cable", 2},
      {"processing-unit", 5},
    },
    result = "roboport-antenna-3",
    energy_required = 0.2
  },
  {
    type = "recipe",
    name = "roboport-antenna-4",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 1},
      {"copper-plate", 1},
      {"copper-cable", 2},
      {"processing-unit", 5},
    },
    result = "roboport-antenna-4",
    energy_required = 0.2
  },
}
)


data:extend(
{
  {
    type = "recipe",
    name = "roboport-chargepad-1",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 2},
      {"advanced-circuit", 5},
    },
    result = "roboport-chargepad-1",
    energy_required = 1
  },
  {
    type = "recipe",
    name = "roboport-chargepad-2",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 2},
      {"advanced-circuit", 5},
      {"battery", 2},
    },
    result = "roboport-chargepad-2",
    energy_required = 1
  },
  {
    type = "recipe",
    name = "roboport-chargepad-3",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 2},
      {"processing-unit", 5},
      {"battery", 2},
    },
    result = "roboport-chargepad-3",
    energy_required = 1
  },
  {
    type = "recipe",
    name = "roboport-chargepad-4",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 2},
      {"processing-unit", 5},
      {"battery", 2},
    },
    result = "roboport-chargepad-4",
    energy_required = 1
  },
}
)


data:extend(
{
  {
    type = "recipe",
    name = "roboport-door-1",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 15},
      {"iron-gear-wheel", 20},
    },
    result = "roboport-door-1",
    energy_required = 1
  },
  {
    type = "recipe",
    name = "roboport-door-2",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 15},
      {"iron-gear-wheel", 20},
    },
    result = "roboport-door-2",
    energy_required = 1
  },
  {
    type = "recipe",
    name = "roboport-door-3",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 15},
      {"iron-gear-wheel", 20},
    },
    result = "roboport-door-3",
    energy_required = 1
  },
  {
    type = "recipe",
    name = "roboport-door-4",
    enabled = "false",
    ingredients =
    {
      {"steel-plate", 15},
      {"iron-gear-wheel", 20},
    },
    result = "roboport-door-4",
    energy_required = 1
  },
}
)


