data:extend(
{
  {
    type = "item-group",
    name = "bobmodules",
    order = "b-m",
    inventory_order = "d-m",
    icon = "__base__/graphics/technology/module.png",
  },

  {
    type = "item-subgroup",
    name = "module-intermediates",
    group = "bobmodules",
    order = "f-0"
  },
  {
    type = "item-subgroup",
    name = "speed-module",
    group = "bobmodules",
    order = "f-1"
  },
  {
    type = "item-subgroup",
    name = "effectivity-module",
    group = "bobmodules",
    order = "f-2"
  },
  {
    type = "item-subgroup",
    name = "productivity-module",
    group = "bobmodules",
    order = "f-3"
  },
  {
    type = "item-subgroup",
    name = "pollution-create-module",
    group = "bobmodules",
    order = "f-4"
  },
  {
    type = "item-subgroup",
    name = "pollution-clean-module",
    group = "bobmodules",
    order = "f-5"
  },
  {
    type = "item-subgroup",
    name = "raw-speed-module",
    group = "bobmodules",
    order = "f-6"
  },
  {
    type = "item-subgroup",
    name = "raw-speed-module-combine",
    group = "bobmodules",
    order = "f-6-1"
  },
  {
    type = "item-subgroup",
    name = "green-module",
    group = "bobmodules",
    order = "f-7"
  },
  {
    type = "item-subgroup",
    name = "green-module-combine",
    group = "bobmodules",
    order = "f-7-1"
  },
  {
    type = "item-subgroup",
    name = "raw-productivity-module",
    group = "bobmodules",
    order = "f-8"
  },
  {
    type = "item-subgroup",
    name = "raw-productivity-module-combine",
    group = "bobmodules",
    order = "f-8-1"
  },
  {
    type = "item-subgroup",
    name = "god-module",
    group = "bobmodules",
    order = "f-9"
  },
  {
    type = "item-subgroup",
    name = "module-beacon",
    group = "bobmodules",
    order = "f-z"
  },
}
)

