data:extend(
{
  {
    type = "module",
    name = "raw-productivity-module-1",
    icon = "__bobmodules__/graphics/icons/red-module-1.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-1",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  },

  {
    type = "module",
    name = "raw-productivity-module-2",
    icon = "__bobmodules__/graphics/icons/red-module-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-2",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = 2 * bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  },

  {
    type = "module",
    name = "raw-productivity-module-3",
    icon = "__bobmodules__/graphics/icons/red-module-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-3",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = 3 * bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  },

  {
    type = "module",
    name = "raw-productivity-module-4",
    icon = "__bobmodules__/graphics/icons/red-module-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-4",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = 4 * bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  },

  {
    type = "module",
    name = "raw-productivity-module-5",
    icon = "__bobmodules__/graphics/icons/red-module-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-5",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = 5 * bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  },

  {
    type = "module",
    name = "raw-productivity-module-6",
    icon = "__bobmodules__/graphics/icons/red-module-6.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-6",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = 6 * bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  },

  {
    type = "module",
    name = "raw-productivity-module-7",
    icon = "__bobmodules__/graphics/icons/red-module-7.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-7",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = 7 * bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  },

  {
    type = "module",
    name = "raw-productivity-module-8",
    icon = "__bobmodules__/graphics/icons/red-module-8.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-productivity-module",
    order = "m-rp-8",
    stack_size = 100,
    default_request_amount = 10,
    effect = { productivity = {bonus = 8 * bobmods.modules.ProductivityPerLevel + bobmods.modules.ProductivityBonus}},
    limitation_message_key = "production-module-usable-only-on-intermeidates"
  }
}
)

