data:extend(
{
  {
    type = "recipe",
    name = "poison-mine",
    enabled = "false",
    energy_required = 5,
    ingredients =
    {
      {"steel-plate", 1},
      {"poison-capsule", 4}
    },
    result = "poison-mine",
    result_count = 4
  },

  {
    type = "recipe",
    name = "slowdown-mine",
    enabled = "false",
    energy_required = 5,
    ingredients =
    {
      {"steel-plate", 1},
      {"slowdown-capsule", 4}
    },
    result = "slowdown-mine",
    result_count = 4
  },

  {
    type = "recipe",
    name = "distractor-mine",
    enabled = "false",
    energy_required = 3.75,
    ingredients =
    {
      {"steel-plate", 1},
      {"distractor-capsule", 1}
    },
    result = "distractor-mine",
    result_count = 3
  },
}
)



