data:extend(
{
  {
    type = "item-subgroup",
    name = "bob-ammo-parts",
    group = "bob-intermediate-products",
    order = "d-a"
  },

  {
    type = "item-subgroup",
    name = "bob-gun",
    group = "combat",
    order = "a-a"
  },
  {
    type = "item-subgroup",
    name = "bob-ammo",
    group = "combat",
    order = "b-a"
  },
  {
    type = "item-subgroup",
    name = "bob-capsule",
    group = "combat",
    order = "c-a"
  },
  {
    type = "item-subgroup",
    name = "bob-armor",
    group = "combat",
    order = "d-a"
  },
  {
    type = "item-subgroup",
    name = "bob-equipment",
    group = "combat",
    order = "e-a"
  },
  {
    type = "item-subgroup",
    name = "bob-defensive-structure",
    group = "combat",
    order = "f-a"
  },
}
)

data:extend(
{
  {
    type = "ammo-category",
    name = "laser-rifle"
  },
  {
    type = "ammo-category",
    name = "artillery-shell"
  },
  {
    type = "ammo-category",
    name = "tank-laser"
  },
}
)

