data:extend(
{
  {
    type = "item",
    name = "poison-mine",
    icon = "__base__/graphics/icons/land-mine.png",
    flags = {"goes-to-quickbar"},
    damage_radius = 5,
    subgroup = "gun",
    order = "f[poison-mine]",
    place_result = "poison-mine",
    stack_size = 20,
    trigger_radius = 1
  },

  {
    type = "item",
    name = "distractor-mine",
    icon = "__base__/graphics/icons/land-mine.png",
    flags = {"goes-to-quickbar"},
    damage_radius = 5,
    subgroup = "gun",
    order = "f[distractor-mine]",
    place_result = "distractor-mine",
    stack_size = 20,
    trigger_radius = 1
  },

  {
    type = "item",
    name = "slowdown-mine",
    icon = "__base__/graphics/icons/land-mine.png",
    flags = {"goes-to-quickbar"},
    damage_radius = 5,
    subgroup = "gun",
    order = "f[slowdown-mine]",
    place_result = "slowdown-mine",
    stack_size = 20,
    trigger_radius = 1
  },
}
)


