--[[ Copyright (c) David-John Miller AKA Anoyomouse 2016
 * Part of the warehousing mod
 *
 * See LICENCE in the project directory for licence information
--]]
require("prototypes.item")
require("prototypes.recipe")
require("prototypes.entity")
require("prototypes.technology")