data:extend(
{ 
	{
		type = "item",
		name = "counter-signal",
		icon = "__LogicBelt__/graphics/belts/counter-belt/counter-signal-v2.png",
		flags = {"goes-to-quickbar"},
		subgroup = "lb-signals",
		order = "a[counter-signal]",
		stack_size = 10
	}
})