data.raw["item"]["basic-accumulator"].order="e[accumulator]-a[basic-accumulator]-a-b"
data.raw["item"]["basic-accumulator"].subgroup = "bob-energy-accumulator"

data:extend(
{
  {
    type = "item",
    name = "large-accumulator",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-a-l",
    place_result = "large-accumulator",
    stack_size = 50
  },

  {
    type = "item",
    name = "fast-accumulator",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-a-f",
    place_result = "fast-accumulator",
    stack_size = 50
  },

  {
    type = "item",
    name = "slow-accumulator",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-a-s",
    place_result = "slow-accumulator",
    stack_size = 50
  },


  {
    type = "item",
    name = "large-accumulator-2",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-b-l",
    place_result = "large-accumulator-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "fast-accumulator-2",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-b-f",
    place_result = "fast-accumulator-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "slow-accumulator-2",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-b-s",
    place_result = "slow-accumulator-2",
    stack_size = 50
  },


  {
    type = "item",
    name = "large-accumulator-3",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-c-l",
    place_result = "large-accumulator-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "fast-accumulator-3",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-c-f",
    place_result = "fast-accumulator-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "slow-accumulator-3",
    icon = "__base__/graphics/icons/basic-accumulator.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-energy-accumulator",
    order = "e[accumulator]-a[basic-accumulator]-c-s",
    place_result = "slow-accumulator-3",
    stack_size = 50
  },
}
)


