function assembler2pipepictures()
  return
  {
    north =
    {
      filename = "__base__/graphics/entity/assembling-machine-2/pipe-north.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {0.09375, 0.4375}
    },
    east =
    {
      filename = "__base__/graphics/entity/assembling-machine-2/pipe-east.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {-0.71875, 0}
    },
    south =
    {
      filename = "__base__/graphics/entity/assembling-machine-2/pipe-south.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {0.0625, -1}
    },
    west =
    {
      filename = "__base__/graphics/entity/assembling-machine-2/pipe-west.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {0.78125, 0.03125}
    }
  }
end

pipecoverspictures = function()
	return {
		north =
		{
			filename = "__base__/graphics/entity/pipe-covers/pipe-cover-north.png",
			priority = "extra-high",
			width = 44,
			height = 32
		},
		east =
		{
			filename = "__base__/graphics/entity/pipe-covers/pipe-cover-east.png",
			priority = "extra-high",
			width = 32,
			height = 32
		},
		south =
		{
			filename = "__base__/graphics/entity/pipe-covers/pipe-cover-south.png",
			priority = "extra-high",
			width = 46,
			height = 52
		},
		west =
		{
			filename = "__base__/graphics/entity/pipe-covers/pipe-cover-west.png",
			priority = "extra-high",
			width = 32,
			height = 32
		}
	}
end

function assembler2pipepicturesCokery()
  return
  {
    north =
    {
      filename = "__Treefarm-AC__/graphics/icons/empty.png",
      priority = "extra-high",
      width = 32,
      height = 32,
      shift = {0.09375, 0.4375}
    },
    east =
    {
      filename = "__base__/graphics/entity/assembling-machine-2/pipe-east.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {-0.71875, 0}
    },
    south =
    {
      filename = "__Treefarm-AC__/graphics/icons/empty.png",
      priority = "extra-high",
      width = 32,
      height = 32,
      shift = {0.0625, -1}
    },
    west =
    {
      filename = "__base__/graphics/entity/assembling-machine-2/pipe-west.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {0.78125, 0.03125}
    }
  }
end

pipecoverspicturesCokery = function()
  return {
    north =
    {
      filename = "__Treefarm-AC__/graphics/icons/empty.png",
      priority = "extra-high",
      width = 32,
      height = 32
    },
    east =
    {
      filename = "__base__/graphics/entity/pipe-covers/pipe-cover-east.png",
      priority = "extra-high",
      width = 32,
      height = 32
    },
    south =
    {
      filename = "__Treefarm-AC__/graphics/icons/empty.png",
      priority = "extra-high",
      width = 32,
      height = 32
    },
    west =
    {
      filename = "__base__/graphics/entity/pipe-covers/pipe-cover-west.png",
      priority = "extra-high",
      width = 32,
      height = 32
    }
  }
end

function assembler2pipepicturesBioreactor()
  return
  {
    north =
    {
      filename = "__Treefarm-AC__/graphics/icons/empty.png",
      priority = "extra-high",
      width = 32,
      height = 32,
      shift = {0.09375, 0.4375}
    },
    east =
    {
      filename = "__Treefarm-AC__/graphics/entities/bioreactor/pipe-east.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {-0.71875, 0}
    },
    south =
    {
      filename = "__Treefarm-AC__/graphics/entities/bioreactor/pipe-south.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {0.0625, -0.8}
    },
    west =
    {
      filename = "__Treefarm-AC__/graphics/entities/bioreactor/pipe-west.png",
      priority = "extra-high",
      width = 41,
      height = 40,
      shift = {0.78125, 0.03125}
    }
  }
end

pipecoverspicturesBioreactor = function()
  return {
    north =
    {
      filename = "__Treefarm-AC__/graphics/icons/empty.png",
      priority = "extra-high",
      width = 32,
      height = 32
    },
    east =
    {
      filename = "__base__/graphics/entity/pipe-covers/pipe-cover-east.png",
      priority = "extra-high",
      width = 32,
      height = 32
    },
    south =
    {
      filename = "__base__/graphics/entity/pipe-covers/pipe-cover-south.png",
      priority = "extra-high",
      width = 46,
      height = 52
    },
    west =
    {
      filename = "__base__/graphics/entity/pipe-covers/pipe-cover-west.png",
      priority = "extra-high",
      width = 32,
      height = 32
    }
  }
end