data:extend(
{
  {
    type = "recipe",
    name = "check-valve",
    energy_required = 2,
    enabled = false,
    ingredients =
    {
      {"steel-plate", 1},
      {"pipe", 1}
    },
    result = "check-valve"
  }
})