data:extend(
{
  {
    type = "recipe",
    name = "science-pack-4",
    enabled = "false",
    energy_required = 15,
    ingredients =
    {
      {"processing-unit", 1},
      {"express-transport-belt", 1},
    },
    result = "science-pack-4"
  },

  {
    type = "recipe",
    name = "lab-2",
    enabled = "false",
    energy_required = 15,
    ingredients =
    {
      {"lab", 1},
      {"advanced-circuit", 10},
      {"smart-inserter", 4},
      {"express-transport-belt", 4}
    },
    result = "lab-2"
  },
}
)

