data:extend(
{
  {
    type = "recipe",
    name = "basic-inserter-left",
    enabled = "true",
    energy_required = 0.5,
    ingredients =
    {
      {"basic-inserter", 1}
    },
    result = "basic-inserter-left"
  },
  {
    type = "recipe",
    name = "basic-inserter-right",
    enabled = "true",
    energy_required = 0.5,
    ingredients =
    {
      {"basic-inserter", 1}
    },
    result = "basic-inserter-right"
  },
  {
    type = "recipe",
    name = "burner-inserter-left",
    enabled = "true",
    energy_required = 0.5,
    ingredients =
    {
      {"burner-inserter", 1}
    },
    result = "burner-inserter-left"
  },
  {
    type = "recipe",
    name = "burner-inserter-right",
    enabled = "true",
    energy_required = 0.5,
    ingredients =
    {
      {"burner-inserter", 1}
    },
    result = "burner-inserter-right"
  },
  {
    type = "recipe",
    name = "fast-inserter-left",
    enabled = "false",
    energy_required = 0.5,
    ingredients =
    {
      {"fast-inserter", 1}
    },
    result = "fast-inserter-left"
  },
  {
    type = "recipe",
    name = "fast-inserter-right",
    enabled = "false",
    energy_required = 0.5,
    ingredients =
    {
      {"fast-inserter", 1}
    },
    result = "fast-inserter-right"
  },
  {
    type = "recipe",
    name = "long-handed-inserter-left",
    enabled = "false",
    energy_required = 0.5,
    ingredients =
    {
      {"long-handed-inserter", 1}
    },
    result = "long-handed-inserter-left"
  },
  {
    type = "recipe",
    name = "long-handed-inserter-right",
    enabled = "false",
    energy_required = 0.5,
    ingredients =
    {
      {"long-handed-inserter", 1}
    },
    result = "long-handed-inserter-right"
  },
  {
    type = "recipe",
    name = "smart-inserter-left",
    enabled = "false",
    energy_required = 0.5,
    ingredients =
    {
      {"smart-inserter", 1}
    },
    result = "smart-inserter-left"
  },
  {
    type = "recipe",
    name = "smart-inserter-right",
    enabled = "false",
    energy_required = 0.5,
    ingredients =
    {
      {"smart-inserter", 1}
    },
    result = "smart-inserter-right"
  }
})