data:extend(
{
  {
    type = "item",
    name = "alien-artifact-red",
    icon = "__bobenemies__/graphics/icons/alien-artifact-red.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-material",
    order = "g[alien-artifact]-b[red]",
    stack_size = 500,
    default_request_amount = 10
  },

  {
    type = "item",
    name = "alien-artifact-orange",
    icon = "__bobenemies__/graphics/icons/alien-artifact-orange.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-material",
    order = "g[alien-artifact]-c[orange]",
    stack_size = 500,
    default_request_amount = 10
  },

  {
    type = "item",
    name = "alien-artifact-yellow",
    icon = "__bobenemies__/graphics/icons/alien-artifact-yellow.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-material",
    order = "g[alien-artifact]-d[yellow]",
    stack_size = 500,
    default_request_amount = 10
  },

  {
    type = "item",
    name = "alien-artifact-green",
    icon = "__bobenemies__/graphics/icons/alien-artifact-green.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-material",
    order = "g[alien-artifact]-e[green]",
    stack_size = 500,
    default_request_amount = 10
  },

  {
    type = "item",
    name = "alien-artifact-blue",
    icon = "__bobenemies__/graphics/icons/alien-artifact-blue.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-material",
    order = "g[alien-artifact]-f[blue]",
    stack_size = 500,
    default_request_amount = 10
  },

  {
    type = "item",
    name = "alien-artifact-purple",
    icon = "__bobenemies__/graphics/icons/alien-artifact-purple.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "raw-material",
    order = "g[alien-artifact]-g[purple]",
    stack_size = 500,
    default_request_amount = 10
  },
}
)



