data:extend(
{
  {
    type = "item",
    name = "hydrogen-canister",
    icon = "__bobplates__/graphics/icons/hydrogen-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-c[hydrogen-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "oxygen-canister",
    icon = "__bobplates__/graphics/icons/oxygen-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-c[oxygen-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "nitrogen-canister",
    icon = "__bobplates__/graphics/icons/nitrogen-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-c[nitrogen-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "chlorine-canister",
    icon = "__bobplates__/graphics/icons/chlorine-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-c[chlorine-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "hydrogen-chloride-canister",
    icon = "__bobplates__/graphics/icons/hydrogen-chloride-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-c[hydrogen-chloride-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "petroleum-gas-canister",
    icon = "__bobplates__/graphics/icons/petroleum-gas-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gas-bottle",
    order = "f-c[petroleum-gas-canister]",
    stack_size = 100
  },


  {
    type = "item",
    name = "heavy-oil-barrel",
    icon = "__bobplates__/graphics/icons/heavy-oil-barrel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-barrel",
    order = "f-c[heavy-oil-barrel]",
    stack_size = 20
  },

  {
    type = "item",
    name = "light-oil-barrel",
    icon = "__bobplates__/graphics/icons/light-oil-barrel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-barrel",
    order = "f-c[light-oil-barrel]",
    stack_size = 20
  },

  {
    type = "item",
    name = "lubricant-barrel",
    icon = "__bobplates__/graphics/icons/lubricant-barrel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-barrel",
    order = "f-c[lubricant-barrel]",
    stack_size = 20
  },

  {
    type = "item",
    name = "sulfuric-acid-barrel",
    icon = "__bobplates__/graphics/icons/sulfuric-acid-barrel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-barrel",
    order = "f-c[sulfuric-acid-barrel]",
    stack_size = 20
  },


  {
    type = "item",
    name = "liquid-fuel-canister",
    icon = "__bobplates__/graphics/icons/liquid-fuel-canister.png",
    flags = {"goes-to-main-inventory"},
    fuel_value = "150MJ",
    subgroup = "bob-barrel",
    order = "f-c[liquid-fuel-canister]",
    stack_size = 100
  },

  {
    type = "item",
    name = "ferric-chloride-canister",
    icon = "__bobplates__/graphics/icons/ferric-chloride-canister.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-barrel",
    order = "f-c[ferric-chloride-canister]",
    stack_size = 100
  },
}
)

