data:extend(
{
  {
    type = "tool",
    name = "alien-science-pack-blue",
    icon = "__bobtech__/graphics/icons/alien-science-pack-blue.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "science-pack",
    order = "e-1[alien-science-pack-blue]",
    stack_size = 200,
    durability = 1,
    durability_description_key = "description.science-pack-remaining-amount"
  },
  {
    type = "tool",
    name = "alien-science-pack-orange",
    icon = "__bobtech__/graphics/icons/alien-science-pack-orange.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "science-pack",
    order = "e-2[alien-science-pack-orange]",
    stack_size = 200,
    durability = 1,
    durability_description_key = "description.science-pack-remaining-amount"
  },
  {
    type = "tool",
    name = "alien-science-pack-purple",
    icon = "__bobtech__/graphics/icons/alien-science-pack-purple.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "science-pack",
    order = "e-3[alien-science-pack-purple]",
    stack_size = 200,
    durability = 1,
    durability_description_key = "description.science-pack-remaining-amount"
  },
  {
    type = "tool",
    name = "alien-science-pack-yellow",
    icon = "__bobtech__/graphics/icons/alien-science-pack-yellow.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "science-pack",
    order = "e-4[alien-science-pack-yellow]",
    stack_size = 200,
    durability = 1,
    durability_description_key = "description.science-pack-remaining-amount"
  },
  {
    type = "tool",
    name = "alien-science-pack-green",
    icon = "__bobtech__/graphics/icons/alien-science-pack-green.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "science-pack",
    order = "e-5[alien-science-pack-green]",
    stack_size = 200,
    durability = 1,
    durability_description_key = "description.science-pack-remaining-amount"
  },
  {
    type = "tool",
    name = "alien-science-pack-red",
    icon = "__bobtech__/graphics/icons/alien-science-pack-red.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "science-pack",
    order = "e-6[alien-science-pack-red]",
    stack_size = 200,
    durability = 1,
    durability_description_key = "description.science-pack-remaining-amount"
  },

  {
    type = "item",
    name = "lab-alien",
    icon = "__bobtech__/graphics/icons/lab-alien.png",
    flags = {"goes-to-quickbar"},
    subgroup = "production-machine",
    order = "g[lab-alien]",
    place_result = "lab-alien",
    stack_size = 10
  },
}
)

