data:extend(
{
  {
    type = "item",
    name = "check-valve",
    icon = "__Check Valve__/graphics/icon/check-valve.png",
    flags = {"goes-to-quickbar"},
    subgroup = "energy-pipe-distribution",
    order = "b[pipe]-c[small-pump]",
    place_result = "check-valve",
    stack_size = 50
  }
})