data:extend(
{ 
	{
		type = "item",
		name = "signal-reader-state",
		icon = "__LogicBelt__/graphics/signals/signal-reader-state/signal-reader-state-v2.png",
		flags = {"goes-to-quickbar"},
		subgroup = "lb-signals",
		order = "b[signal-reader-state]",
		stack_size = 3
	}
})