data:extend(
{
  {
    type = "item",
    name = "small-alien-artifact-red",
    icon = "__bobenemies__/graphics/icons/small-alien-artifact-red.png",
    flags = { "goes-to-main-inventory" },
    subgroup = "raw-material",
    order = "g[alien-artifact]-b[red]-a[small]",
    stack_size = 500,
    default_request_amount = 100
  },
  {
    type = "recipe",
    name = "alien-artifact-red-from-small",
    result = "alien-artifact-red",
    ingredients =
    {
      {"small-alien-artifact-red", 25}
    },
    energy_required = 1,
    enabled = "true",
    category = "crafting"
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "small-alien-artifact-orange",
    icon = "__bobenemies__/graphics/icons/small-alien-artifact-orange.png",
    flags = { "goes-to-main-inventory" },
    subgroup = "raw-material",
    order = "g[alien-artifact]-c[orange]-a[small]",
    stack_size = 500,
    default_request_amount = 100
  },
  {
    type = "recipe",
    name = "alien-artifact-orange-from-small",
    result = "alien-artifact-orange",
    ingredients =
    {
      {"small-alien-artifact-orange", 25}
    },
    energy_required = 1,
    enabled = "true",
    category = "crafting"
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "small-alien-artifact-yellow",
    icon = "__bobenemies__/graphics/icons/small-alien-artifact-yellow.png",
    flags = { "goes-to-main-inventory" },
    subgroup = "raw-material",
    order = "g[alien-artifact]-d[yellow]-a[small]",
    stack_size = 500,
    default_request_amount = 100
  },
  {
    type = "recipe",
    name = "alien-artifact-yellow-from-small",
    result = "alien-artifact-yellow",
    ingredients =
    {
      {"small-alien-artifact-yellow", 25}
    },
    energy_required = 1,
    enabled = "true",
    category = "crafting"
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "small-alien-artifact-green",
    icon = "__bobenemies__/graphics/icons/small-alien-artifact-green.png",
    flags = { "goes-to-main-inventory" },
    subgroup = "raw-material",
    order = "g[alien-artifact]-e[green]-a[small]",
    stack_size = 500,
    default_request_amount = 100
  },
  {
    type = "recipe",
    name = "alien-artifact-green-from-small",
    result = "alien-artifact-green",
    ingredients =
    {
      {"small-alien-artifact-green", 25}
    },
    energy_required = 1,
    enabled = "true",
    category = "crafting"
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "small-alien-artifact-blue",
    icon = "__bobenemies__/graphics/icons/small-alien-artifact-blue.png",
    flags = { "goes-to-main-inventory" },
    subgroup = "raw-material",
    order = "g[alien-artifact]-f[blue]-a[small]",
    stack_size = 500,
    default_request_amount = 100
  },
  {
    type = "recipe",
    name = "alien-artifact-blue-from-small",
    result = "alien-artifact-blue",
    ingredients =
    {
      {"small-alien-artifact-blue", 25}
    },
    energy_required = 1,
    enabled = "true",
    category = "crafting"
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "small-alien-artifact-purple",
    icon = "__bobenemies__/graphics/icons/small-alien-artifact-purple.png",
    flags = { "goes-to-main-inventory" },
    subgroup = "raw-material",
    order = "g[alien-artifact]-g[purple]-a[small]",
    stack_size = 500,
    default_request_amount = 100
  },
  {
    type = "recipe",
    name = "alien-artifact-purple-from-small",
    result = "alien-artifact-purple",
    ingredients =
    {
      {"small-alien-artifact-purple", 25}
    },
    energy_required = 1,
    enabled = "true",
    category = "crafting"
  },
}
)



