-- Side inserters have a shoter distance to travel, slowing down to compensate
SIDE_SPEED_FACTOR = 0.70
-- Setting this flag to false appears to fix distorted/harsh sound bugs
MATCH_SOUND_PROGRESS_TO_ACTIVITY = false

require("prototypes.entities")
require("prototypes.items")
require("prototypes.recipes")
require("prototypes.technology")