data:extend(
{ 
	{
		type = "item",
		name = "temperature-signal",
		icon = "__LogicBelt__/graphics/pipes/temperature-signal/temperature-signal-v2.png",
		flags = {"goes-to-quickbar"},
		subgroup = "lb-signals",
		order = "c[temperature-signal]",
		stack_size = 999
	}
})