data.raw.item["gun-turret"].order = "b[turret]-a[gun-turret-1]"
data.raw.item["laser-turret"].order = "b[turret]-b[laser-turret-1]"

data:extend(
{
  {
    type = "item",
    name = "bob-gun-turret-2",
    icon = "__base__/graphics/icons/gun-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-a[gun-turret-2]",
    place_result = "bob-gun-turret-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-gun-turret-3",
    icon = "__base__/graphics/icons/gun-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-a[gun-turret-3]",
    place_result = "bob-gun-turret-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-gun-turret-4",
    icon = "__base__/graphics/icons/gun-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-a[gun-turret-4]",
    place_result = "bob-gun-turret-4",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-gun-turret-5",
    icon = "__base__/graphics/icons/gun-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-a[gun-turret-5]",
    place_result = "bob-gun-turret-5",
    stack_size = 50
  },


  {
    type = "item",
    name = "bob-sniper-turret-1",
    icon = "__base__/graphics/icons/gun-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-c[sniper-turret-1]",
    place_result = "bob-sniper-turret-1",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-sniper-turret-2",
    icon = "__base__/graphics/icons/gun-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-c[sniper-turret-2]",
    place_result = "bob-sniper-turret-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-sniper-turret-3",
    icon = "__base__/graphics/icons/gun-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-c[sniper-turret-3]",
    place_result = "bob-sniper-turret-3",
    stack_size = 50
  },


  {
    type = "item",
    name = "bob-laser-turret-2",
    icon = "__base__/graphics/icons/laser-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-b[laser-turret-2]",
    place_result = "bob-laser-turret-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-laser-turret-3",
    icon = "__base__/graphics/icons/laser-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-b[laser-turret-3]",
    place_result = "bob-laser-turret-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-laser-turret-4",
    icon = "__base__/graphics/icons/laser-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-b[laser-turret-4]",
    place_result = "bob-laser-turret-4",
    stack_size = 50
  },

  {
    type = "item",
    name = "bob-laser-turret-5",
    icon = "__base__/graphics/icons/laser-turret.png",
    flags = {"goes-to-quickbar"},
    subgroup = "defensive-structure",
    order = "b[turret]-b[laser-turret-5]",
    place_result = "bob-laser-turret-5",
    stack_size = 50
  },
}
)

