data:extend(
{
  {
    type = "item",
    name = "bronze-alloy",
    icon = "__bobplates__/graphics/icons/plate/bronze-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-a[bronze]",
    stack_size = 200
  },
  {
    type = "item",
    name = "brass-alloy",
    icon = "__bobplates__/graphics/icons/plate/brass-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-b[brass]",
    stack_size = 200
  },
  {
    type = "item",
    name = "electrum-alloy",
    icon = "__bobplates__/graphics/icons/plate/electrum-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-c[electrum]",
    stack_size = 200
  },
  {
    type = "item",
    name = "copper-tungsten-alloy",
    icon = "__bobplates__/graphics/icons/plate/copper-tungsten-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-d[copper-tungsten]",
    stack_size = 200
  },
  {
    type = "item",
    name = "tungsten-carbide",
    icon = "__bobplates__/graphics/icons/plate/tungsten-carbide-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-d[tungsten-carbide]",
    stack_size = 200
  },
  {
    type = "item",
    name = "gunmetal-alloy",
    icon = "__bobplates__/graphics/icons/plate/gunmetal-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-e[gunmetal]",
    stack_size = 200
  },

  {
    type = "item",
    name = "invar-alloy",
    icon = "__bobplates__/graphics/icons/plate/invar-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-f[invar]",
    stack_size = 200
  },
  {
    type = "item",
    name = "nitinol-alloy",
    icon = "__bobplates__/graphics/icons/plate/nitinol-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-g[nitinol]",
    stack_size = 200
  },
  {
    type = "item",
    name = "cobalt-steel-alloy",
    icon = "__bobplates__/graphics/icons/plate/cobalt-steel-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-alloy",
    order = "c-b-i[cobalt-steel]",
    stack_size = 200
  },
}
)

