data:extend(
{
  {
    type = "fluid",
    name = "sulfuric-nitric-acid",
    default_temperature = 25,
    heat_capacity = "1KJ",
    base_color = {r=0.0, g=0.0, b=1.0},
    flow_color = {r=1.0, g=1.0, b=0.0},
    max_temperature = 100,
    icon = "__bobwarfare__/graphics/icons/sulfuric-nitric-acid.png",
    pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
    order = "a[fluid]-g[sulfuric-nitric-acid]"
  },

  {
    type = "fluid",
    name = "nitroglycerin",
    default_temperature = 25,
    heat_capacity = "1KJ",
    base_color = {r=0.3, g=0.3, b=1.0},
    flow_color = {r=1.0, g=0.3, b=0.3},
    max_temperature = 100,
    icon = "__bobwarfare__/graphics/icons/nitroglycerin.png",
    pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
    order = "a[fluid]-g[nitroglycerin]"
  },

  {
    type = "fluid",
    name = "glycerol",
    default_temperature = 25,
    heat_capacity = "1KJ",
    base_color = {r=1.0, g=1.0, b=0.5},
    flow_color = {r=0.5, g=0.5, b=0.5},
    max_temperature = 100,
    icon = "__bobwarfare__/graphics/icons/glycerol.png",
    pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
    order = "a[fluid]-g[glycerol]"
  },
}
)


