require("prototypes.items")
require("prototypes.recipies")
require("prototypes.recipe-categories")
require("prototypes.technologies")
require("prototypes.liquids")
require("prototypes.buildingPrototypes")
require("prototypes.ammoPrototypes")