--[[ Copyright (c) David-John Miller AKA Anoyomouse 2016
 * Part of the warehousing mod
 *
 * See LICENCE in the project directory for licence information
--]]
require "defines"
require "config"

local WAREHOUSING_VERSION = "0.0.6"


