data:extend(
{
  {
    type = "item",
    name = "tin-plate",
    icon = "__bobplates__/graphics/icons/plate/tin-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-a[tin-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "silver-plate",
    icon = "__bobplates__/graphics/icons/plate/silver-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-c[silver-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "lead-plate",
    icon = "__bobplates__/graphics/icons/plate/lead-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-f[lead-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "gold-plate",
    icon = "__bobplates__/graphics/icons/plate/gold-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-d[gold-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "nickel-plate",
    icon = "__bobplates__/graphics/icons/plate/nickel-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-f[nickel-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "zinc-plate",
    icon = "__bobplates__/graphics/icons/plate/zinc-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-b[zinc-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "aluminium-plate",
    icon = "__bobplates__/graphics/icons/plate/aluminium-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-g[aluminium-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "titanium-plate",
    icon = "__bobplates__/graphics/icons/plate/titanium-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-h[titanium-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "tungsten-plate",
    icon = "__bobplates__/graphics/icons/plate/tungsten-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-i[tungsten-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "silicon",
    icon = "__bobplates__/graphics/icons/plate/silicon-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-e[silicon-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "lithium",
    icon = "__bobplates__/graphics/icons/plate/lithium-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-e[lithium-plate]",
    stack_size = 200
  },
  {
    type = "item",
    name = "cobalt-plate",
    icon = "__bobplates__/graphics/icons/plate/cobalt-plate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-material",
    order = "c-a-j[cobalt-plate]",
    stack_size = 200
  },
}
)

