data.raw.item["chemical-plant"].stack_size = 50
data.raw.item["chemical-plant"].subgroup = "bob-chemical-machine"
data.raw.item["chemical-plant"].order = "e[chemical-plant-1]"

data:extend(
{
  {
    type = "item",
    name = "electrolyser",
    icon = "__bobplates__/graphics/icons/electrolyser.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-electrolyser-machine",
    order = "e[electrolyser-1]",
    place_result = "electrolyser",
    stack_size = 50
  },
  {
    type = "item",
    name = "electrolyser-2",
    icon = "__bobplates__/graphics/icons/electrolyser-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-electrolyser-machine",
    order = "e[electrolyser-2]",
    place_result = "electrolyser-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "electrolyser-3",
    icon = "__bobplates__/graphics/icons/electrolyser-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-electrolyser-machine",
    order = "e[electrolyser-3]",
    place_result = "electrolyser-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "electrolyser-4",
    icon = "__bobplates__/graphics/icons/electrolyser-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-electrolyser-machine",
    order = "e[electrolyser-4]",
    place_result = "electrolyser-4",
    stack_size = 50
  },

  {
    type = "item",
    name = "mixing-furnace",
    icon = "__bobplates__/graphics/icons/stone-mixing-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[mixing-furnace]",
    place_result = "mixing-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "electric-mixing-furnace",
    icon = "__bobplates__/graphics/icons/electric-mixing-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "c[electric-mixing-furnace]",
    place_result = "electric-mixing-furnace",
    stack_size = 50
  },

  {
    type = "item",
    name = "chemical-boiler",
    icon = "__bobplates__/graphics/icons/stone-chemical-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[chemical-boiler]",
    place_result = "chemical-boiler",
    stack_size = 50
  },
  {
    type = "item",
    name = "chemical-furnace",
    icon = "__bobplates__/graphics/icons/chemical-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "c[chemical-furnace]",
    place_result = "chemical-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "electric-chemical-mixing-furnace",
    icon = "__bobplates__/graphics/icons/electric-chemical-mixing-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "d[electric-chemical-mixing-furnace-1]",
    place_result = "electric-chemical-mixing-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "electric-chemical-mixing-furnace-2",
    icon = "__bobplates__/graphics/icons/electric-chemical-mixing-furnace-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "d[electric-chemical-mixing-furnace-2]",
    place_result = "electric-chemical-mixing-furnace-2",
    stack_size = 50
  },


  {
    type = "item",
    name = "chemical-plant-2",
    icon = "__bobplates__/graphics/icons/chemical-plant-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-chemical-machine",
    order = "e[chemical-plant-2]",
    place_result = "chemical-plant-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "chemical-plant-3",
    icon = "__bobplates__/graphics/icons/chemical-plant-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-chemical-machine",
    order = "e[chemical-plant-3]",
    place_result = "chemical-plant-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "chemical-plant-4",
    icon = "__bobplates__/graphics/icons/chemical-plant-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-chemical-machine",
    order = "e[chemical-plant-4]",
    place_result = "chemical-plant-4",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump",
    icon = "__bobplates__/graphics/icons/air-pump-1.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-1]",
    place_result = "air-pump",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-2",
    icon = "__bobplates__/graphics/icons/air-pump-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-2]",
    place_result = "air-pump-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-3",
    icon = "__bobplates__/graphics/icons/air-pump-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-3]",
    place_result = "air-pump-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-4",
    icon = "__bobplates__/graphics/icons/air-pump-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-4]",
    place_result = "air-pump-4",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump",
    icon = "__bobplates__/graphics/icons/water-pump-1.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-1]",
    place_result = "water-pump",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-2",
    icon = "__bobplates__/graphics/icons/water-pump-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-2]",
    place_result = "water-pump-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-3",
    icon = "__bobplates__/graphics/icons/water-pump-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-3]",
    place_result = "water-pump-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-4",
    icon = "__bobplates__/graphics/icons/water-pump-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-4]",
    place_result = "water-pump-4",
    stack_size = 50
  },


  {
    type = "item",
    name = "void-pump",
    icon = "__bobplates__/graphics/icons/void-pump.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "void-pump",
    place_result = "void-pump",
    stack_size = 50
  },
}
)

