data:extend({
	{
		type = "item-group",
		name = "logic-belt",
		order = "l",
		inventory_order = "l",
		icon = "__LogicBelt__/graphics/group.png",
	},
	{
		type = "item-subgroup",
		name = "lb-signals",
		group = "logic-belt",
		order = "00"
	},
	{
		type = "item-subgroup",
		name = "lb-belts",
		group = "logic-belt",
		order = "01"
	},
	{
		type = "item-subgroup",
		name = "lb-pipes",
		group = "logic-belt",
		order = "02"
	},
	{
		type = "item-subgroup",
		name = "lb-rail-signals",
		group = "logic-belt",
		order = "03"
	},
})