data:extend(
{
  {
    type = "recipe",
    name = "bob-ruby-3",
    category = "crafting-machine",
    energy_required = 1,
    ingredients =
    {
      {"ruby-ore", 1},
    },
    result = "ruby-3",
    result_count = 4
  },
  {
    type = "recipe",
    name = "bob-sapphire-3",
    category = "crafting-machine",
    energy_required = 1,
    ingredients =
    {
      {"sapphire-ore", 1},
    },
    result = "sapphire-3",
    result_count = 4
  },
  {
    type = "recipe",
    name = "bob-emerald-3",
    category = "crafting-machine",
    energy_required = 1,
    ingredients =
    {
      {"emerald-ore", 1},
    },
    result = "emerald-3",
    result_count = 4
  },
  {
    type = "recipe",
    name = "bob-amethyst-3",
    category = "crafting-machine",
    energy_required = 1,
    ingredients =
    {
      {"amethyst-ore", 1},
    },
    result = "amethyst-3",
    result_count = 4
  },
  {
    type = "recipe",
    name = "bob-topaz-3",
    category = "crafting-machine",
    energy_required = 1,
    ingredients =
    {
      {"topaz-ore", 1},
    },
    result = "topaz-3",
    result_count = 4
  },
  {
    type = "recipe",
    name = "bob-diamond-3",
    category = "crafting-machine",
    energy_required = 1,
    ingredients =
    {
      {"diamond-ore", 1},
    },
    result = "diamond-3",
    result_count = 4
  },


  {
    type = "recipe",
    name = "bob-ruby-4",
    category = "crafting-with-fluid",
    enabled = false,
    energy_required = 3.5,
    ingredients =
    {
      {"ruby-3", 1},
      {"grinding-wheel", 1},
      {type="fluid", name="water", amount=1},
    },
    result = "ruby-4",
  },
  {
    type = "recipe",
    name = "bob-sapphire-4",
    category = "crafting-with-fluid",
    enabled = false,
    energy_required = 3.5,
    ingredients =
    {
      {"sapphire-3", 1},
      {"grinding-wheel", 1},
      {type="fluid", name="water", amount=1},
    },
    result = "sapphire-4",
  },
  {
    type = "recipe",
    name = "bob-emerald-4",
    category = "crafting-with-fluid",
    enabled = false,
    energy_required = 3.5,
    ingredients =
    {
      {"emerald-3", 1},
      {"grinding-wheel", 1},
      {type="fluid", name="water", amount=1},
    },
    result = "emerald-4",
  },
  {
    type = "recipe",
    name = "bob-amethyst-4",
    category = "crafting-with-fluid",
    enabled = false,
    energy_required = 3.5,
    ingredients =
    {
      {"amethyst-3", 1},
      {"grinding-wheel", 1},
      {type="fluid", name="water", amount=1},
    },
    result = "amethyst-4",
  },
  {
    type = "recipe",
    name = "bob-topaz-4",
    category = "crafting-with-fluid",
    enabled = false,
    energy_required = 3.5,
    ingredients =
    {
      {"topaz-3", 1},
      {"grinding-wheel", 1},
      {type="fluid", name="water", amount=1},
    },
    result = "topaz-4",
  },
  {
    type = "recipe",
    name = "bob-diamond-4",
    category = "crafting-with-fluid",
    enabled = false,
    energy_required = 3.5,
    ingredients =
    {
      {"diamond-3", 1},
      {"grinding-wheel", 1},
      {type="fluid", name="water", amount=1},
    },
    result = "diamond-4",
  },


  {
    type = "recipe",
    name = "bob-ruby-5",
    category = "crafting-machine",
    enabled = false,
    energy_required = 17.5,
    ingredients =
    {
      {"ruby-4", 1},
      {"polishing-wheel", 1},
      {"polishing-compound", 1},
    },
    result = "ruby-5",
  },
  {
    type = "recipe",
    name = "bob-sapphire-5",
    category = "crafting-machine",
    enabled = false,
    energy_required = 17.5,
    ingredients =
    {
      {"sapphire-4", 1},
      {"polishing-wheel", 1},
      {"polishing-compound", 1},
    },
    result = "sapphire-5",
  },
  {
    type = "recipe",
    name = "bob-emerald-5",
    category = "crafting-machine",
    enabled = false,
    energy_required = 17.5,
    ingredients =
    {
      {"emerald-4", 1},
      {"polishing-wheel", 1},
      {"polishing-compound", 1},
    },
    result = "emerald-5",
  },
  {
    type = "recipe",
    name = "bob-amethyst-5",
    category = "crafting-machine",
    enabled = false,
    energy_required = 17.5,
    ingredients =
    {
      {"amethyst-4", 1},
      {"polishing-wheel", 1},
      {"polishing-compound", 1},
    },
    result = "amethyst-5",
  },
  {
    type = "recipe",
    name = "bob-topaz-5",
    category = "crafting-machine",
    enabled = false,
    energy_required = 17.5,
    ingredients =
    {
      {"topaz-4", 1},
      {"polishing-wheel", 1},
      {"polishing-compound", 1},
    },
    result = "topaz-5",
  },
  {
    type = "recipe",
    name = "bob-diamond-5",
    category = "crafting-machine",
    enabled = false,
    energy_required = 17.5,
    ingredients =
    {
      {"diamond-4", 1},
      {"polishing-wheel", 1},
      {"polishing-compound", 1},
    },
    result = "diamond-5",
  },
}
)

