data:extend(
{
  {
    type = "module",
    name = "green-module-1",
    icon = "__bobmodules__/graphics/icons/yellow-module-1.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-1",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -1 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -1 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },

  {
    type = "module",
    name = "green-module-2",
    icon = "__bobmodules__/graphics/icons/yellow-module-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-2",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -2 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -2 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },

  {
    type = "module",
    name = "green-module-3",
    icon = "__bobmodules__/graphics/icons/yellow-module-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-3",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -3 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -3 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },

  {
    type = "module",
    name = "green-module-4",
    icon = "__bobmodules__/graphics/icons/yellow-module-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-4",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -4 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -4 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },

  {
    type = "module",
    name = "green-module-5",
    icon = "__bobmodules__/graphics/icons/yellow-module-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-5",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -5 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -5 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },

  {
    type = "module",
    name = "green-module-6",
    icon = "__bobmodules__/graphics/icons/yellow-module-6.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-6",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -6 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -6 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },

  {
    type = "module",
    name = "green-module-7",
    icon = "__bobmodules__/graphics/icons/yellow-module-7.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-7",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -7 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -7 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },

  {
    type = "module",
    name = "green-module-8",
    icon = "__bobmodules__/graphics/icons/yellow-module-8.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "green-module",
    order = "m-g-8",
    stack_size = 100,
    default_request_amount = 10,
    effect =
    {
      pollution = {bonus = -8 * bobmods.modules.PollutionPerLevel - bobmods.modules.PollutionBonus},
      consumption = {bonus = -8 * bobmods.modules.ConsumptionPerLevel - bobmods.modules.ConsumptionBonus}
    }
  },
}
)

