data:extend(
{
  {
    type = "item",
    name = "basic-inserter-left",
    icon = "__Side Inserters__/graphics/icons/basic-inserter-left.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "b[basic-inserter]a",
    place_result = "basic-inserter-left",
    stack_size = 50
  },
  {
    type = "item",
    name = "basic-inserter-right",
    icon = "__Side Inserters__/graphics/icons/basic-inserter-right.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "b[basic-inserter]b",
    place_result = "basic-inserter-right",
    stack_size = 50
  },
  {
    type = "item",
    name = "burner-inserter-left",
    icon = "__Side Inserters__/graphics/icons/burner-inserter-left.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "a[burner-inserter]a",
    place_result = "burner-inserter-left",
    stack_size = 50
  },
  {
    type = "item",
    name = "burner-inserter-right",
    icon = "__Side Inserters__/graphics/icons/burner-inserter-right.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "a[burner-inserter]b",
    place_result = "burner-inserter-right",
    stack_size = 50
  },
  {
    type = "item",
    name = "fast-inserter-left",
    icon = "__Side Inserters__/graphics/icons/fast-inserter-left.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "d[fast-inserter]a",
    place_result = "fast-inserter-left",
    stack_size = 50
  },
  {
    type = "item",
    name = "fast-inserter-right",
    icon = "__Side Inserters__/graphics/icons/fast-inserter-right.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "d[fast-inserter]b",
    place_result = "fast-inserter-right",
    stack_size = 50
  },
  {
    type = "item",
    name = "long-handed-inserter-left",
    icon = "__Side Inserters__/graphics/icons/long-handed-inserter-left.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "c[long-handed-inserter]a",
    place_result = "long-handed-inserter-left",
    stack_size = 50
  },
  {
    type = "item",
    name = "long-handed-inserter-right",
    icon = "__Side Inserters__/graphics/icons/long-handed-inserter-right.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "c[long-handed-inserter]b",
    place_result = "long-handed-inserter-right",
    stack_size = 50
  },
  {
    type = "item",
    name = "smart-inserter-left",
    icon = "__Side Inserters__/graphics/icons/smart-inserter-left.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "f[inserter]-e[smart-inserter]a",
    place_result = "smart-inserter-left",
    stack_size = 50
  },
  {
    type = "item",
    name = "smart-inserter-right",
    icon = "__Side Inserters__/graphics/icons/smart-inserter-right.png",
    flags = {"goes-to-quickbar"},
    subgroup = "inserter",
    order = "f[inserter]-e[smart-inserter]b",
    place_result = "smart-inserter-right",
    stack_size = 50
  }
})