data:extend(
{
  {
    type = "armor",
    name = "heavy-armor-2",
    icon = "__bobwarfare__/graphics/icons/heavy-armor-2.png",
    flags = {"goes-to-main-inventory"},
    resistances =
    {
      {
        type = "physical",
        decrease = 8,
        percent = 35
      },
      {
        type = "acid",
        decrease = 7,
        percent = 35
      },
      {
        type = "explosion",
        decrease = 15,
        percent = 40
      },
    },
    durability = 8000,
    subgroup = "armor",
    order = "c-a",
    stack_size = 10
  },
  {
    type = "armor",
    name = "heavy-armor-3",
    icon = "__bobwarfare__/graphics/icons/heavy-armor-3.png",
    flags = {"goes-to-main-inventory"},
    resistances =
    {
      {
        type = "physical",
        decrease = 10,
        percent = 40
      },
      {
        type = "acid",
        decrease = 10,
        percent = 40
      },
      {
        type = "explosion",
        decrease = 20,
        percent = 50
      },
      {
        type = "impact",
        decrease = 15,
        percent = 25
      },
      {
        type = "poison",
        percent = 25
      },
    },
    durability = 12000,
    subgroup = "armor",
    order = "c-b",
    stack_size = 10
  },

  {
    type = "armor",
    name = "bob-power-armor-mk3",
    icon = "__bobwarfare__/graphics/icons/power-armor-mk3.png",
    flags = {"goes-to-main-inventory"},
    resistances = 
    {
      {
        type = "physical",
        decrease = 12,
        percent = 45
      },
      {
        type = "acid",
        decrease = 12,
        percent = 45
      },
      {
        type = "explosion",
        decrease = 20,
        percent = 50
      },
      {
        type = "impact",
        decrease = 10,
        percent = 30
      },
      {
        type = "poison",
        decrease = 10,
        percent = 30
      },
      {
        type = "fire",
        decrease = 10,
        percent = 30
      },
      {
        type = "laser",
        decrease = 10,
        percent = 30
      },
    },
    durability = 30000,
    subgroup = "armor",
    order = "f[power-armor-mk3]",
    stack_size = 1,
    equipment_grid = {width = 12, height = 12}
  },

  {
    type = "armor",
    name = "bob-power-armor-mk4",
    icon = "__bobwarfare__/graphics/icons/power-armor-mk4.png",
    flags = {"goes-to-main-inventory"},
    resistances = 
    {
      {
        type = "physical",
        decrease = 15,
        percent = 50
      },
      {
        type = "acid",
        decrease = 15,
        percent = 50
      },
      {
        type = "explosion",
        decrease = 20,
        percent = 50
      },
      {
        type = "impact",
        decrease = 15,
        percent = 40
      },
      {
        type = "poison",
        decrease = 15,
        percent = 40
      },
      {
        type = "fire",
        decrease = 15,
        percent = 40
      },
      {
        type = "laser",
        decrease = 15,
        percent = 40
      },
    },
    durability = 40000,
    subgroup = "armor",
    order = "g[power-armor-mk4]",
    stack_size = 1,
    equipment_grid = {width = 14, height = 14}
  },

  {
    type = "armor",
    name = "bob-power-armor-mk5",
    icon = "__bobwarfare__/graphics/icons/power-armor-mk5.png",
    flags = {"goes-to-main-inventory"},
    resistances = 
    {
      {
        type = "physical",
        decrease = 20,
        percent = 50
      },
      {
        type = "acid",
        decrease = 20,
        percent = 50
      },
      {
        type = "explosion",
        decrease = 20,
        percent = 50
      },
      {
        type = "impact",
        decrease = 20,
        percent = 50
      },
      {
        type = "poison",
        decrease = 20,
        percent = 50
      },
      {
        type = "fire",
        decrease = 20,
        percent = 50
      },
      {
        type = "laser",
        decrease = 20,
        percent = 50
      },
    },
    durability = 50000,
    subgroup = "armor",
    order = "h[power-armor-mk5]",
    stack_size = 1,
    equipment_grid = {width = 16, height = 16}
  },
}
)
