if not bobmods then bobmods = {} end
if not bobmods.lib then bobmods.lib = {} end


require("item-functions")
require("technology-functions")
require("module-functions")
require("recipe-functions")
require("ore-functions")
require("category-functions")

